@@ -18,7 +18,7 @@ module HTTP
       end
 
       def http_version
-        @parser.http_version.join('.')
+        @parser.http_version.join(".")
       end
 
       def status_code
@@ -42,10 +42,9 @@ module HTTP
       end
 
       def chunk
-        if (chunk = @chunk)
-          @chunk = nil
-          chunk
-        end
+        chunk  = @chunk
+        @chunk = nil
+        chunk
       end
 
       def on_message_complete
